@@ -75,16 +75,10 @@ newfile() {
 
 mkdir -p "$MMS_BASE_DIR"
 
-if command -v systemctl > /dev/null; then
-	SERVICE="systemctl --user"
-else
-	SERVICE=superctl
-fi
-
-$SERVICE stop mmsd-tng
+systemctl --user stop mmsd-tng
 
 finish() {
-	$SERVICE start mmsd-tng
+	systemctl --user start mmsd-tng
 }
 trap 'finish' EXIT
 
