@@ -1,10 +1,12 @@
 #!/bin/sh
-# configversion: ca786817fd3d00b79f8c59a947da7289
+# configversion: 0fa59a4972de3206fa31a04b2eb23ab0
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
 # This hook is called when the system becomes unlocked again
 
+# include common definitions
+# shellcheck source=scripts/core/sxmo_common.sh
 . sxmo_common.sh
 
 sxmo_log "transitioning to stage unlock"
@@ -21,10 +23,8 @@ superctl start sxmo_hook_lisgd
 # the periodic mutex check is necessary to 'free' old mutex, I think.
 if ! [ -e "$XDG_CACHE_HOME/sxmo/sxmo.nosuspend" ]; then
 	sxmo_daemons.sh start idle_locker sxmo_idle.sh -w \
-		timeout "${SXMO_UNLOCK_IDLE_TIME:-120}" 'sxmo_daemons.sh start crustin sxmo_run_periodically.sh 5 sh -c "sxmo_hook_check_state_mutexes.sh && exec sxmo_mutex.sh can_suspend holdexec sxmo_suspend.sh"' \
+		timeout "${SXMO_UNLOCK_IDLE_TIME:-120}" 'sxmo_daemons.sh start crustin sxmo_run_periodically.sh 5 sh -c "sxmo_uniq_exec.sh sxmo_hook_check_state_mutexes.sh && exec sxmo_mutex.sh can_suspend holdexec sxmo_suspend.sh"' \
 		resume 'sxmo_daemons.sh stop crustin' \
-		timeout "$((${SXMO_UNLOCK_IDLE_TIME:-120}+10))" 'sxmo_daemons.sh start periodic_state_mutex_check sxmo_run_periodically.sh 10 sxmo_hook_check_state_mutexes.sh' \
+		timeout "$((${SXMO_UNLOCK_IDLE_TIME:-120}+10))" 'sxmo_daemons.sh start periodic_state_mutex_check sxmo_run_periodically.sh 10 sxmo_uniq_exec.sh sxmo_hook_check_state_mutexes.sh' \
 		resume 'sxmo_daemons.sh stop periodic_state_mutex_check'
 fi
-
-sxmo_superd_signal.sh sxmo_desktop_widget -USR2
