@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 044ccc23931bd0e5d0a4880de326d60c
+# configversion: 27538f7293527f58c6f44839c69aeb85
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 # shellcheck disable=SC2154
@@ -38,6 +38,7 @@ write_line_app epiphany "$icon_glb Epiphany" "epiphany"
 write_line_app epy "$icon_bok Epy" "sxmo_terminal.sh epy"
 write_line_app evince "$icon_bok Evince" "evince"
 write_line_app firefox "$icon_ffx Firefox" "firefox"
+write_line_app firefox-esr "$icon_ffx Firefox ESR" "firefox-esr"
 write_line_app foliate "$icon_bok Foliate" "foliate"
 ( [ "$SXMO_WM" = sway ] && command -v foot >/dev/null) && \
 	write_line "$icon_trm Foot" "foot $SHELL"
@@ -106,6 +107,7 @@ write_line_app weechat "$icon_msg Weechat" "sxmo_terminal.sh weechat"
 write_line_app pavucontrol "$icon_mus Pavucontrol" "pavucontrol"
 write_line_app w3m "$icon_glb W3m" "sxmo_terminal.sh w3m duck.com"
 write_line_app vim "$icon_vim Vim" "sxmo_terminal.sh vim"
+write_line_app vimb "$icon_glb Vimb" "vimb"
 write_line_app vis "$icon_vim Vis" "sxmo_terminal.sh vis"
 write_line_app vlc "$icon_mvi Vlc" "vlc"
 write_line_app vte-2.91 "$icon_trm VTE 3" "vte-2.91"
