@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 7292827f22d7dd4a5d356c3f6658e210
+# configversion: 7f068f412238f290951d79e11a704cad
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -47,8 +47,16 @@ else
 	free_suspend_mutex "Hotspot is active"
 fi
 
+ssh_connected() {
+	netstat -tn | awk '
+		BEGIN { status = 1 }
+		$4 ~ /:22$/ { status = 0; exit }
+		END { exit status }
+		'
+}
+
 # active_ssh
-if netstat -tn | grep ESTABLISHED | cut -d':' -f2 | grep -q '^22 '; then
+if ssh_connected; then
 	lock_suspend_mutex "SSH is connected"
 else
 	free_suspend_mutex "SSH is connected"
@@ -70,7 +78,7 @@ fi
 
 # mpris compatible media player
 if command -v playerctl > /dev/null; then
-	if test "$(playerctl status)" = "Playing"; then
+	if test "$(playerctl status 2>/dev/null)" = "Playing"; then
 		lock_suspend_mutex "MPRIS client is playing"
 	else
 		free_suspend_mutex "MPRIS client is playing"
