@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: bbf3065d8cdf8e8c2ca6382c3c091772
+# configversion: e2bb8efca5e835fd6021753c63d11605
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -81,17 +81,6 @@ case "$WMCLASS" in
 				printf %b "$icon_tof" ||  printf %b "$icon_ton";
 				printf %b "^ 1 ^ doas sxmo_bluetoothtoggle.sh && sxmo_hook_statusbar.sh bluetooth"
 			)
-			$icon_wif Wifi $(
-				if rfkill list wifi | grep -q "yes"; then
-					printf %b "$icon_tof"
-					printf %b "^ 1 ^ doas sxmo_wifitoggle.sh"
-				else
-					printf %b "$icon_ton"
-					# fake trigger to update status bar
-					devicename="$(nmcli -t c show --active | grep '802-11-wireless' | cut -d':' -f4)"
-					printf %b "^ 1 ^ doas sxmo_wifitoggle.sh && sxmo_hook_statusbar.sh network wifi \"$devicename\""
-				fi
-			)
 			$(test "$SXMO_WM" = dwm && printf %b "$icon_cfg Invert Colors ^ 1 ^ xcalib -a -invert")
 			$icon_clk Change Timezone            ^ 1 ^ sxmo_timezonechange.sh
 			$icon_zzz Auto-suspend $(
@@ -124,10 +113,10 @@ case "$WMCLASS" in
 			$icon_lck Lock               ^ 0 ^ sxmo_hook_lock.sh
 			$icon_lck Lock (Screen off)  ^ 0 ^ sxmo_hook_screenoff.sh
 			$icon_zzz Suspend            ^ 0 ^ sxmo_hook_screenoff.sh && sxmo_suspend.sh
-			$icon_out Logout             ^ 0 ^ confirm Logout && (pkill dwm || swaymsg exit)
-			$([ -f /usr/share/xsessions/sxmo.desktop ] &&
-				[ -f /usr/share/wayland-sessions/swmo.desktop ] &&
-				echo "$icon_rol Toggle WM ^ 0 ^ confirm Toggle && sxmo_wmtoggle.sh"
+			$icon_out Logout             ^ 0 ^ confirm Logout && sxmo_power.sh logout
+			$([ -f "$(xdg_data_path xsessions/sxmo.desktop)" ] &&
+				[ -f "$(xdg_data_path wayland-sessions/swmo.desktop)" ] &&
+				echo "$icon_rol Toggle WM ^ 0 ^ confirm Toggle && sxmo_power.sh togglewm"
 			)
 			$icon_rld Reboot             ^ 0 ^ confirm Reboot && sxmo_power.sh reboot
 			$icon_pwr Poweroff           ^ 0 ^ confirm Poweroff && sxmo_power.sh poweroff
@@ -553,6 +542,17 @@ case "$WMCLASS" in
 		"
 		WINNAME=Firefox
 		;;
+	*vimb*)
+		CHOICES="
+			$icon_glb Navigate        ^ 0 ^ sxmo_type -k Escape o && sxmo_keyboard.sh open
+			$icon_zmi Zoom            ^ 1 ^ sxmo_type -k Escape zi
+			$icon_zmo Zoom            ^ 1 ^ sxmo_type -k Escape zo
+			$icon_arl History         ^ 1 ^ sxmo_type -M Ctrl o
+			$icon_arr History         ^ 1 ^ sxmo_type -M Ctrl i
+			$icon_rld Refresh         ^ 0 ^ sxmo_type -k Escape r
+		"
+		WINNAME=Vimb
+		;;
 	*geopard*)
 		# Geopard
 		CHOICES="
