@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: d98d5ab7966299682be8f55471bb14ef
+# configversion: bd58e89a3288dc502bdb49ef7b3896e6
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -27,8 +27,8 @@ icon_aru=""
 icon_att=""
 icon_bel=""
 icon_bok=""
-icon_btd="" # bluethooth device
 icon_bth="" # bluetooth
+icon_cal=""
 icon_cam=""
 icon_cfg="" #configuration cog
 icon_chk=""
@@ -36,12 +36,14 @@ icon_chs="♜" #chess
 icon_clc="" #calculator
 icon_clk=""
 icon_cls="" #close
+icon_com="" # (Laptop) Computer (💻)
 icon_cpy=""
 icon_del="﫧" #delete
 icon_dir="" #directory folder
 icon_dof="" # dot off
 icon_don="" # dot on
 icon_dot="" # searching, connecting, etc.
+icon_drw="" # Drawing tablet
 icon_ear="" # earpiece
 icon_edt="" #editor
 icon_eml="" #email
@@ -54,6 +56,7 @@ icon_fil="" #file
 icon_fll="" #flashlight
 icon_flt="" #filter/pipe
 icon_fnd="" #search/find
+icon_gam="" # gaming controller (🎮)
 icon_glb="" #globe
 icon_gps='' #gps
 icon_grd=""
@@ -73,8 +76,9 @@ icon_mdd="" # modem disabled state
 icon_mic=""
 icon_mmc=""
 icon_mnu=""
-icon_mod="" # modem
+icon_mod="" # modem
 icon_mov=""
+icon_mse="" # computer mouse (🖱️)
 icon_msg="" #text
 icon_mus=""
 icon_mut="" #mute
@@ -89,6 +93,7 @@ icon_phn="" #phone
 icon_phx="" #hangup
 icon_plk="" # phone locked
 icon_pls=""
+icon_prn="🖶" # printer (🖨️)
 icon_prv="" #previous
 icon_pst=""
 icon_pwr="⏻" #power
@@ -120,7 +125,10 @@ icon_usr=""
 icon_vid="" #video
 icon_vim=''
 icon_wif=""
+icon_wfo="睊" # wifi off
+icon_wfh="" # wifi hotspot
 icon_win="" #window
+icon_wat="" # watch (⌚)
 icon_wn2=""
 icon_wrh=""
 icon_wtr="" #weather
