@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 5c3602778af8ef07454032f74ca6b164
+# configversion: 16e379c1ff6984208606e6524bd9ab96
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -7,8 +7,9 @@
 
 # kill existing ring playback
 if [ -e "$XDG_RUNTIME_DIR/sxmo.ring.pid" ]; then
-	MPVID="$(cat "$XDG_RUNTIME_DIR/sxmo.ring.pid")"
-	kill "$MPVID"
+	xargs -r kill < "$XDG_RUNTIME_DIR/sxmo.ring.pid"
 	rm "$XDG_RUNTIME_DIR/sxmo.ring.pid"
 fi
 
+sxmo_playerctl.sh pause_all
+
