@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 2d45489ba66592b6a9047113b7ea8194
+# configversion: 04f2fc0891ccdadc2cd73216c648c8fb
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -17,17 +17,15 @@
 # shellcheck source=scripts/core/sxmo_common.sh
 . sxmo_common.sh
 
-case "$(cat "$XDG_CONFIG_HOME"/sxmo/.ringmode)" in
-	Mute)
-		;;
-	Vibrate)
+# do nothing if active call
+if ! sxmo_modemcall.sh list_active_calls | grep -q active; then
+
+	if [ ! -f "$XDG_CONFIG_HOME"/sxmo/.noring ]; then
+		mpv --no-resume-playback --quiet --no-video "$SXMO_TEXTSOUND" >/dev/null &
+	fi
+
+	if [ ! -f "$XDG_CONFIG_HOME"/sxmo/.novibrate ]; then
 		sxmo_vibrate 500
-		;;
-	Ring)
-		mpv --no-resume-playback --quiet --no-video "$SXMO_TEXTSOUND"
-		;;
-	*) #Default: ring&vibrate
-		mpv --no-resume-playback --quiet --no-video "$SXMO_TEXTSOUND" &
-		sxmo_vibrate 500
-		;;
-esac
+	fi
+
+fi
